@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the BiCePS Linear Integer Solver (BLIS).             *
  *                                                                           *
- * BLIS is distributed under the Common Public License as part of the        *
+ * BLIS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2009, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2013, Lehigh University, Yan Xu, and Ted Ralphs.       *
  * All Rights Reserved.                                                      *
  *===========================================================================*/
 
@@ -53,6 +53,8 @@ BlisBranchStrategyPseudo::BlisBranchStrategyPseudo (
     bestNumberUp_ = rhs.bestNumberUp_;
     bestChangeDown_ = rhs.bestChangeDown_;
     bestNumberDown_ = rhs.bestNumberDown_;
+    relibility_ = rhs.relibility_;
+    type_ = rhs.type_;
 }
 
 //#############################################################################
@@ -99,7 +101,8 @@ BlisBranchStrategyPseudo::betterBranchObject(BcpsBranchObject * thisOne,
 
 /** Create a set of candidate branching objects. */
 int 
-BlisBranchStrategyPseudo::createCandBranchObjects(int numPassesLeft)
+BlisBranchStrategyPseudo::createCandBranchObjects(int numPassesLeft,
+						  double ub)
 {
     int bStatus = 0;
     int i, pass, colInd;
